biosimulators_utils.viz.vega package — BioSimulators utils 0.1.154 documentation

# biosimulators_utils.viz.vega package

## Subpackages

- biosimulators_utils.viz.vega.escher package
  - Submodules
  - biosimulators_utils.viz.vega.escher.core module
- biosimulators_utils.viz.vega.ginml package
  - Submodules
  - biosimulators_utils.viz.vega.ginml.core module
- biosimulators_utils.viz.vega.sbgn package
  - Submodules
  - biosimulators_utils.viz.vega.sbgn.core module

## Submodules

## biosimulators_utils.viz.vega.utils module

Utilities for working with Vega

Author

  Jonathan Karr <karr@mssm.edu>

Date

  2021-07-22

Copyright

  2021, Center for Reproducible Biomedical Modeling

License

  MIT

biosimulators_utils.viz.vega.utils.dict_to_vega_dataset(data_dict)

  Convert a dictionary of values, such as that produced by COBRApy, into a Vega dataset (array of data elements)

  Parameters

    data_dict (`dict`) – dictionary that maps the labels of predicted variables to their predicted values

  Returns

    list of data elements, each with two keys `label` and values` whose values

      are the labels of each variable and an array of their predicted values

  Return type

    `list`